==> makeen-expressionengine-0.0.51.tgz: package/src/compiler/parts/bracketPart.ts <==
﻿import { expressionPart } from './expressionPart';
import expressionData from '../../expressionData';
import { groupDataContext } from '../../functions/groupDataContext';
import  {format}  from "typescript-dotnet-commonjs/System/Text/Utility";
import { compoundPart } from './compoundPart';
import { malformedExpressionException } from '../../error/malformedExpressionException';
import List from 'typescript-dotnet-commonjs/System/Collections/List';
import { outputVariables } from '../../utils/outputVariables';

export class bracketPart extends compoundPart {

    public get subParts(): List<expressionPart> {
        return (new List<expressionPart>()).add(this._expression);
    }

    public get simpleName(): string {
        return "Item";
    }
    private _bracketEnded: boolean = false;

    public get BracketEnded(): boolean {
        return this._bracketEnded;
    }
    public set BracketEnded(value: boolean) {
        this._bracketEnded = value;
    }
    private _expression!: expressionPart;
    public get Expression(): expressionPart {
        return this._expression;
    }
    public set Expression(value: expressionPart) {
        this._expression = value;
    }

    public canAcceptMore(): boolean {
        return !this.BracketEnded;
    }

    public addSubPart(part: expressionPart): boolean {
        if (!this.BracketEnded) {
            this.Expression = part;
        }
        else {
            throw new malformedExpressionException();
        }

        return true;
    }

    public toString(): string {
        return format("({0})", this.Expression);
    }

    public resolve(expressionData: expressionData, /* out */resolved: outputVariables, running: groupDataContext, evaluateAllContexts: boolean = true, setValue: Object | undefined= undefined): Object | undefined {
        return this.Expression.resolve(expressionData, /* out */resolved, running, evaluateAllContexts, setValue);
    }
}

==> makeen-expressionengine-0.0.63.tgz: package/src/compiler/parts/bracketPart.ts <==
﻿import { expressionPart } from './expressionPart';
import expressionData from '../../expressionData';
import { groupDataContext } from '../../functions/groupDataContext';
import  {format}  from "typescript-dotnet-commonjs/System/Text/Utility";
import { compoundPart } from './compoundPart';
import { malformedExpressionException } from '../../error/malformedExpressionException';
import List from 'typescript-dotnet-commonjs/System/Collections/List';
import { outputVariables } from '../../utils/outputVariables';

export class bracketPart extends compoundPart {

     get subParts(): expressionPart[] {
        let lst: expressionPart[] = [];
        lst.push(this._expression);
        return lst;
    }

     get simpleName(): string {
        return "Item";
    }
    private _bracketEnded: boolean = false;

     get BracketEnded(): boolean {
        return this._bracketEnded;
    }
     set BracketEnded(value: boolean) {
        this._bracketEnded = value;
    }
    private _expression!: expressionPart;
     get Expression(): expressionPart {
        return this._expression;
    }
     set Expression(value: expressionPart) {
        this._expression = value;
    }

     canAcceptMore(): boolean {
        return !this.BracketEnded;
    }

     addSubPart(part: expressionPart): boolean {
        if (!this.BracketEnded) {
            this.Expression = part;
        }
        else {
            throw new malformedExpressionException();
        }

        return true;
    }

     toString(): string {
        return format("({0})", this.Expression);
    }

     resolve(expressionData: expressionData, /* out */resolved: outputVariables, running: groupDataContext, evaluateAllContexts: boolean = true, setValue: Object | undefined= undefined): Object | undefined {
        return this.Expression.resolve(expressionData, /* out */resolved, running, evaluateAllContexts, setValue);
    }
}
